package com.autocareai.mvvmdemo.common.http

import androidx.lifecycle.LifecycleOwner
import com.autocareai.lib.net.converter.IConverter
import com.autocareai.lib.net.exception.BusinessErrorException
import com.autocareai.lib.util.JsonUtil
import okhttp3.ResponseBody
import org.json.JSONObject
import retrofit2.Response

/**
 * <pre>
 *     author : louis wang
 *     time   : 2020/06/28
 *     desc   : 将Http响应数据转换成一个列表，去除最外层封装
 *     version: 1.0
 * </pre>
 */
class ResponseListConverter<D>(private val clazz: Class<D>) : IConverter<ArrayList<D>> {

    override fun convertResponse(
        owner: LifecycleOwner?,
        response: Response<ResponseBody>
    ): ArrayList<D>? {
        val json = response.body()?.string() ?: return null
        val jsonObj = JSONObject(json)

        val code = jsonObj.getInt("errorCode")
        if (code == 0) {
            return JsonUtil.parseArray(jsonObj.getJSONArray("data").toString(), clazz)
        } else {
            throw BusinessErrorException(code, jsonObj.getString("errorMsg"))
        }
    }
}