package com.autocareai.mvvmdemo.demo.main

import com.autocareai.lib.lifecycle.extension.post
import com.autocareai.lib.lifecycle.livedata.SingleLiveEvent
import com.autocareai.mvvmdemo.R
import com.autocareai.mvvmdemo.common.view.BaseViewModel
import com.autocareai.mvvmdemo.demo.api.DemoApi
import com.autocareai.mvvmdemo.demo.enity.UserEntity

/**
 * <pre>
 *     author : Taylor Zhang
 *     time   : 2020/06/24
 *     desc   : 主界面ViewModel
 *     version: 1.0.0
 * </pre>
 */
class MainViewModel : BaseViewModel() {

    /**
     * 跳转至列表界面事件
     */
    val toListEvent = SingleLiveEvent<UserEntity>()

    /**
     * 登录
     */
    fun login(phone: String, password: String) {
        checkInput(phone, password)
    }

    private fun checkInput(phone: String, password: String) {
        // TODO: 2020/6/24 检查用户输入是否合规的逻辑也应该放在ViewModel中
        if (phone.isEmpty()) {
            shortToast(R.string.main_please_input_phone)
            return
        }

        if (password.isEmpty()) {
            shortToast(R.string.main_please_input_password)
            return
        }

        realLogin(phone, password)
    }

    private fun realLogin(phone: String, password: String) {
        DemoApi.login(phone, password)
            .onSuccess {
                shortToast(R.string.main_login_success)
                toListEvent.post(it)
            }
            .onError { _, message ->
                shortToast(message)
            }
            .async()
    }
}